@@ -1,10 +1,10 @@
 package Net::DNS::Resolver::Base;
 
 #
-# $Id: Base.pm 1449 2016-02-01 12:27:12Z willem $
+# $Id: Base.pm 1453 2016-02-05 12:11:01Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1449 $)[1];
+$VERSION = (qw$LastChangedRevision: 1453 $)[1];
 
 
 use strict;
@@ -43,7 +43,7 @@ use constant USE_SOCKET => defined eval {
 	import IO::Socket;
 };
 
-use constant USE_SOCKET_IP => defined eval { require IO::Socket::IP; };
+use constant USE_SOCKET_IP => scalar eval { require IO::Socket::IP; Socket->VERSION > 1.98 };
 
 use constant USE_SOCKET_INET => defined eval { require IO::Socket::INET; };
 
@@ -99,7 +99,7 @@ sub _untaint {
 		udppacketsize	=> 0,	# value bounded below by PACKETSZ
 		force_v4	=> ( IPv6 ? 0 : 1 ),
 		force_v6	=> 0,	# only relevant if IPv6 is supported
-		prefer_v4	=> 1,	# prefer v6 by default
+		prefer_v4	=> ( IPv6 ? 1 : 0 ),
 		},
 			__PACKAGE__;
 
